# Minicli

Expose functions in the command line. Minimalist and pythonic.

Supports annotations and async functions.

## Requirements

- Python >= 3.6


## Install

    pip install minicli


## Documentation

See [https://minicli.readthedocs.org](https://minicli.readthedocs.org)


## Run tests

    pip install -r requirements-dev.txt
    python setup.py develop
    py.test
